'use strict';
exports.__esModule = true;
var react_native_1 = require("react-native");
var MSSpeech = react_native_1.NativeModules.MSSpeech;
// NativeEventEmitter is only availabe on React Native platforms, so this conditional is used to avoid import conflicts in the browser/server
var voiceEmitter = (react_native_1.Platform.OS !== "web" && MSSpeech) ? new react_native_1.NativeEventEmitter(MSSpeech) : null;
var RCTMSSpeech = /** @class */ (function () {
    function RCTMSSpeech() {
        this._loaded = false;
        this._listeners = null;
        this._events = {
            'onSpeechStart': this._onSpeechStart.bind(this),
            'onSpeechRecognized': this._onSpeechRecognized.bind(this),
            'onSpeechEnd': this._onSpeechEnd.bind(this),
            'onSpeechError': this._onSpeechError.bind(this),
            'onSpeechResult': this._onSpeechResult.bind(this),
            'onSpeechPartialResult': this._onSpeechPartialResult.bind(this)
        };
    }
    RCTMSSpeech.prototype.removeAllListeners = function () {
        MSSpeech.onSpeechStart = null;
        MSSpeech.onSpeechRecognized = null;
        MSSpeech.onSpeechEnd = null;
        MSSpeech.onSpeechError = null;
        MSSpeech.onSpeechResult = null;
        MSSpeech.onSpeechPartialResult = null;
    };
    RCTMSSpeech.prototype.destroy = function () {
        var _this = this;
        if (!this._loaded && !this._listeners) {
            return Promise.resolve();
        }
        return new Promise(function (resolve, reject) {
            MSSpeech.destroySpeech(function (error) {
                if (error) {
                    reject(new Error(error));
                }
                else {
                    if (_this._listeners) {
                        _this._listeners.map(function (listener, index) { return listener.remove(); });
                        _this._listeners = null;
                    }
                    resolve();
                }
            });
        });
    };
    RCTMSSpeech.prototype.setKeyAndRegion = function (key, region) {
        if (MSSpeech) {
            MSSpeech.setKeyAndRegion(key, region);
        }
    };
    RCTMSSpeech.prototype.start = function (locale, options) {
        var _this = this;
        if (options === void 0) { options = {}; }
        if (!this._loaded && !this._listeners && voiceEmitter !== null) {
            this._listeners = Object.keys(this._events)
                .map(function (key, index) { return voiceEmitter.addListener(key, _this._events[key]); });
        }
        return new Promise(function (resolve, reject) {
            var callback = function (error) {
                if (error) {
                    reject(new Error(error));
                }
                else {
                    resolve();
                }
            };
            if (react_native_1.Platform.OS === 'android') {
                MSSpeech.startSpeech(locale, Object.assign({
                    EXTRA_LANGUAGE_MODEL: "LANGUAGE_MODEL_FREE_FORM",
                    EXTRA_MAX_RESULTS: 5,
                    EXTRA_PARTIAL_RESULTS: true,
                    REQUEST_PERMISSIONS_AUTO: true
                }, options), callback);
            }
            else {
                // MSSpeech.startSpeech(callback);
            }
        });
    };
    RCTMSSpeech.prototype.stop = function () {
        if (!this._loaded && !this._listeners) {
            return Promise.resolve();
        }
        return new Promise(function (resolve, reject) {
            MSSpeech.stopSpeech(function (error) {
                if (error) {
                    reject(new Error(error));
                }
                else {
                    resolve();
                }
            });
        });
    };
    RCTMSSpeech.prototype.cancel = function () {
        if (!this._loaded && !this._listeners) {
            return Promise.resolve();
        }
        return new Promise(function (resolve, reject) {
            MSSpeech.cancelSpeech(function (error) {
                if (error) {
                    reject(new Error(error));
                }
                else {
                    resolve();
                }
            });
        });
    };
    RCTMSSpeech.prototype.isAvailable = function () {
        return true;
    };
    RCTMSSpeech.prototype.isRecognizing = function () {
        return new Promise(function (resolve, reject) {
            MSSpeech.isRecognizing(function (isRecognizing) { return resolve(isRecognizing); });
        });
    };
    RCTMSSpeech.prototype._onSpeechStart = function (e) {
        if (this.onSpeechStart) {
            this.onSpeechStart(e);
        }
    };
    RCTMSSpeech.prototype._onSpeechRecognized = function (e) {
        if (this.onSpeechRecognized) {
            this.onSpeechRecognized(e);
        }
    };
    RCTMSSpeech.prototype._onSpeechEnd = function (e) {
        if (this.onSpeechEnd) {
            this.onSpeechEnd(e);
        }
    };
    RCTMSSpeech.prototype._onSpeechError = function (e) {
        if (this.onSpeechError) {
            this.onSpeechError(e);
        }
    };
    RCTMSSpeech.prototype._onSpeechResult = function (e) {
        if (this.onSpeechResult) {
            this.onSpeechResult(e);
        }
    };
    RCTMSSpeech.prototype._onSpeechPartialResult = function (e) {
        if (this.onSpeechPartialResult) {
            this.onSpeechPartialResult(e);
        }
    };
    return RCTMSSpeech;
}());
exports.RCTMSSpeech = RCTMSSpeech;
var speech = new RCTMSSpeech();
exports["default"] = speech;
//# sourceMappingURL=index.js.map